import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { getAllRoleList, setRoleStatus } from '@/api/system/role/role';
import { useMessage } from '@/hooks/web/useMessage';
import Icon from '@/components/Icon/Icon.vue';
import { setMenuStatus } from '@/api/system/menu/menu';
import { min } from 'xe-utils';

type CheckedType = boolean | string | number;
export const columns: BasicColumn[] = [
  {
    title: '菜单名称',
    dataIndex: 'menuName',
    width: 50,
    align: 'left',
    colProps: { span: 8 },
  },
];

export const ModelFormSchema: FormSchema[] = [
  {
    field: 'createDate',
    label: '操作时间',
    component: 'Input',
    rules: [
      {
        // required: true,
        message: '请输入操作时间',
      },
    ],
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'managerName',
    label: '操作人',
    component: 'Input',
    rules: [
      {
        // required: true,
        message: '请输入操作人',
      },
    ],
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'manageType',
    label: '操作类型',
    component: 'Select',
    rules: [
      {
        // required: true,
        message: '请选择操作类型',
      },
    ],
    componentProps: {
      disabled: true,
      options: [
        {
          value: '1',
          label: '全部操作类型',
        },
        {
          value: '2',
          label: '自定操作类型',
        },
        {
          value: '3',
          label: '本部门操作类型',
        },
        {
          value: '4',
          label: '本部门及以下操作类型',
        },
        {
          value: '5',
          label: '仅本人操作类型',
        },
      ],
    },
  },
  {
    label: '对象名称',
    field: 'ObjectName',
    component: 'Input',
    // ifShow: false,
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '路径',
    field: 'url',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '对象类型',
    field: 'objectType',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '操作结果',
    field: 'result',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
];
export const ModelFormSchematab2: FormSchema[] = [
  {
    field: 'createDate',
    label: '访问时间',
    component: 'Input',
    rules: [
      {
        // required: true,
        message: '请输入访问时间',
      },
    ],
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'accessUser',
    label: '访问用户',
    component: 'Input',
    rules: [
      {
        // required: true,
        message: '请输入访问用户',
      },
    ],
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'accessType',
    label: '访问途径',
    component: 'Select',
    rules: [
      {
        // required: true,
        message: '请选择访问途径',
      },
    ],
    componentProps: {
      disabled: true,
      options: [
        {
          value: '1',
          label: '全部操作类型',
        },
        {
          value: '2',
          label: '自定操作类型',
        },
        {
          value: '3',
          label: '本部门操作类型',
        },
        {
          value: '4',
          label: '本部门及以下操作类型',
        },
        {
          value: '5',
          label: '仅本人操作类型',
        },
      ],
    },
  },
  {
    label: '服务器IP/主机名',
    field: 'serverIp',
    component: 'Input',
    // ifShow: false,
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '数据源名称',
    field: 'dataSourceName',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '数据源类型',
    field: 'dataSourceType',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '关联sql语句',
    field: 'sql',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '执行结束时间',
    field: 'endTime',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '执行耗时',
    field: 'costTime',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    label: '访问结果',
    field: 'result',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
];
export const physicalModelFormSchema: any[] = [
  {
    field: 'Selection',
    label: '清理选择',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      options: [
        {
          value: '1',
          label: '保留全部日志',
        },
        {
          value: '2',
          label: '保留某日开始的全部日志',
        },
        {
          value: '3',
          label: '设定日志最长保留多少天',
        },
      ],
    },
  },
  {
    field: 'date',
    label: '日期',
    component: 'DatePicker',
    ifShow: ({ values }) => values.Selection === '2',
    componentProps: {
      placeholder: '请输入日期',
    },
  },
  {
    field: 'days',
    label: '天数',
    component: 'InputNumber',
    ifShow: ({ values }) => values.Selection === '3',
    componentProps: {
      placeholder: '请输入天数',
      min: 1,
    },
  },
];
